@@ -9,9 +9,9 @@
 # Last modification : 21-Nov-2016
 # -----------------------------------------------------------------------------
 
-from .command   import run, parse, convert
+from .command   import run, parse, parseString, convert
 
-VERSION    = "0.6.5"
+VERSION    = "0.7.0"
 LICENSE    = "http://ffctn.com/doc/licenses/bsd"
 
 __doc__ = """
@@ -20,6 +20,8 @@ engine <http://github.com/sebastien/parsing>, which sadly has an important
 performance penalty, but offers greated easy of development/update.
 """
 
+process = parseString
+
 if __name__ == "__main__":
 	import sys
 	run(sys.argv[1:])
